@@ -16,7 +16,7 @@
 def test_tweet_iterator():
     import os
     import gzip
-    from b4msa.utils import tweet_iterator
+    from microtc.utils import tweet_iterator
     
     fname = os.path.dirname(__file__) + '/text.json'
     a = [x for x in tweet_iterator(fname)]
@@ -33,7 +33,7 @@ def test_tweet_iterator():
 
 def test_textmodel():
     from b4msa.textmodel import TextModel
-    from b4msa.utils import tweet_iterator
+    from microtc.utils import tweet_iterator
     import os
     fname = os.path.dirname(__file__) + '/text.json'
     tw = list(tweet_iterator(fname))
@@ -48,7 +48,7 @@ def test_params():
     import itertools
     from b4msa.params import BASIC_OPTIONS
     from b4msa.textmodel import TextModel
-    from b4msa.utils import tweet_iterator
+    from microtc.utils import tweet_iterator
 
     params = dict(del_diac=[True, False], usr_option=BASIC_OPTIONS,
                   url_option=BASIC_OPTIONS)
@@ -164,27 +164,28 @@ def test_negations_italian():
 
 def test_textmodel_entropy():
     from b4msa.textmodel import TextModel
-    from b4msa.utils import tweet_iterator
+    from microtc.utils import tweet_iterator
     import os
     fname = os.path.dirname(__file__) + '/text.json'
     tw = list(tweet_iterator(fname))
     text = TextModel(tw, threshold=0.01)
     assert isinstance(text, TextModel)
     print(len(text.model._w2id))
-    assert len(text.model._w2id) == 233
+    assert len(text.model._w2id) == 39
 
 
 def test_textmodel_token_min_filter():
     from b4msa.textmodel import TextModel
-    from b4msa.utils import tweet_iterator
+    from microtc.utils import tweet_iterator
     import os
     fname = os.path.dirname(__file__) + '/text.json'
     tw = list(tweet_iterator(fname))
     text = TextModel(tw, token_min_filter=1)
-    assert len(text.model._w2id) == 28
+    print(len(text.model._w2id))
+    assert len(text.model._w2id) == 62
     text = TextModel(tw, token_min_filter=0.3)
     print(len(text.model._w2id))
-    assert len(text.model._w2id) == 4
+    assert len(text.model._w2id) == 13
     text = TextModel(tw, token_min_filter=1, threshold=0.01)
 
 
@@ -200,3 +201,17 @@ def test_textmodel_default():
     text = TextModel(lang='arabic', stopwords='xxx')
     assert text._lang_kw['stopwords'] == 'xxx'
     
+def test_textmodel_chinese():
+    from b4msa.textmodel import TextModel
+    tm = TextModel(lang='zh')
+    assert tm.lang.lang == 'chinese'
+    tm.tokenize('聊聊呗')
+
+
+def test_textmodel_get_word_list():
+    from b4msa.textmodel import get_word_list_zh
+    text = '~聊聊呗~'
+    for hy, y in zip(get_word_list_zh(text),
+                     ['聊聊', '呗']):
+        assert y == hy
+    
